#!/usr/bin/python3
import os


_migrationTypeList = {
    '10-table'     :{},
    '15-table-link':{},
    '20-function'  :{},
    '30-procedure' :{},
    '40-view'      :{},
    '50-index'     :{},
    '60-forein'    :{},
    '70-migration' :{},
    '80-seed'      :{},
    '90-event'     :{},
    '95-admin'     :{}
}



def init():
    os.mkdir('panthera')
    for i in _migrationTypeList:
        os.mkdir('panthera/'+i)


def check():
    if os.path.isdir('panthera') == False:
        return print('Directory is missing')
    for i in _migrationTypeList:
        if os.path.isdir('panthera/'+i) == False:
           return print('Directory is not complet')
    print('Directory Structure is healthy')

def fix():
    if os.path.isdir('panthera') == False:
        os.mkdir('panthera')
    for i in _migrationTypeList:
        if os.path.isdir('panthera/'+i) == False:
           os.mkdir('panthera/'+i)
    print('Directory structure is fixed')

def _reader(target):
    out = {}
    target_path = ('panthera/'+target)
    if os.path.isdir('panthera') == False:
       return print('Directory is missing')
    for i in os.listdir(target_path):
        if os.path.isfile(target_path+i):
           with open(target_path+i) as f:
               out[i]=str(f.read())
    return out



def readTable():
    name = '10-table'
    _migrationTypeList[name] = _reader(name)
    return _migrationTypeList[name]

def readTableLink():
    name = '15-table-link'
    _migrationTypeList[name] = _reader(name)
    return _migrationTypeList[name]

def readFunction():
    _migrationTypeList['20-function'] = _reader('20-function')
    return _migrationTypeList['20-function']

def readProcedure():
    name = '30-procedure'
    _migrationTypeList[name] = _reader(name)
    return _migrationTypeList[name]

def readView():
    name = '40-view'
    _migrationTypeList[name] = _reader(name)
    return _migrationTypeList[name]

def readIndex():
    name = '50-index'
    _migrationTypeList[name] = _reader(name)
    return _migrationTypeList[name]

def readForein():
    name = '60-forein'
    _migrationTypeList[name] = _reader(name)
    return _migrationTypeList[name]

def readMigration():
    name = '70-migration'
    _migrationTypeList[name] = _reader(name)
    return _migrationTypeList[name]

def readSeed():
    name = '80-seed'
    _migrationTypeList[name] = _reader(name)
    return _migrationTypeList[name]

def readEvent():
    name = '90-event'
    _migrationTypeList[name] = _reader(name)
    return _migrationTypeList[name]

def readAdmin():
    name = '95-admin'
    _migrationTypeList[name] = _reader(name)
    return _migrationTypeList[name]




#!/usr/bin/python

import directory
import display
import hashlib
import mariadb
import config
import time
import sys
import os

_p = display.echo

_config = config.read('mariadb')

_migrationTypeList = [
    '10-table',
    '15-table-link',
    '20-function',
    '30-procedure',
    '40-view',
    '50-index',
    '60-forein',
    '70-migration',
    '80-seed',
    '90-event',
    '95-admin'
]


_table_query = """

CREATE TABLE IF NOT EXISTS panthera_migration (
    id INT UNSIGNED NOT NULL AUTO_INCREMENT,
    migration INT UNSIGNED NOT NULL,
    file VARCHAR(256) NOT NULL,
    hash VARCHAR(512),
    date INT UNSIGNED NOT NULL
    PRIMARY KEY ( id )
);

"""

try:
    conn = mariadb.connect(
        user=_config.user,
        password=config.password,
        host=config.host,
        port=_config.port,
        database=_config.database
    )
except mariadb.Error as e:
    print(f"MariaDb died in my arm: {e}")
    sys.exit(1)

_conn.autocommit = True
_cur = conn.cursor()

def _sha256(string):
    crypto = hashlib.new('sha256')
    crypto.update(
        bytes(string ,encoding='utf8')
    )
    return crypto.hexdigest()


def buildTable():
    tables = directory.readTable()
    for table in  tables:
        if not checkExitBuildScript('table', table):
            _cur.execute(tables[table])
            _insertBuildScript('table', table, tables[table]):
            _p('Table "'+str(tsble)+'" executed')

def buildTableLink():
    links = directory.readTableLink()
    for link in  links:
        if not checkExitBuildScript('link', link):
            _cur.execute(links[link])
            _insertBuildScript('link', link, links[link]):
            _p('Link "'+str(link)+'" executed')


def buildFunction():
    functions = directory.readFunction()
    for function in  functions:
        if not checkExitBuildScript('function', function):
            _cur.execute(functions[function])
            _insertBuildScript('function', function, functions[function]):
            _p('Function "'+str(function)+'" executed')

def buildProcedure():
    procedures = directory.readProcedure()
    for procedure in  procedures:
        if not checkExitBuildScript('procedure', procedure):
            _cur.execute(procedures[procedure])
            _insertBuildScript('procedure', procedure, procedures[procedure]):
            _p('Procedure "'+str(procudere)+'" executed')

def buildView():
    views = directory.readView()
    for view in  views:
        if not checkExitBuildScript('view', view):
            _cur.execute(views[view])
            _insertBuildScript('view', view, views[view]):
            _p('View "'+str(view)+'" executed')

def buildIndex():
    indexs = directory.readIndex()
    for index in  indexs:
        if not checkExitBuildScript('index', index):
            _cur.execute(indexs[index])
            _insertBuildScript('index', index, indexs[index]):
            _p('Index "'+str(index)+'" executed')

def buildForein():
    foreins = directory.readForein()
    for forein in  foreins:
        if not checkExitBuildScript('forein', forein):
            _cur.execute(foreins[forein])
            _insertBuildScript('forein', forein, foreins[forein]):
            _p('Forein "'+str(forein)+'" executed')

def buildMigration():
    migrations = directory.readMigration()
    for migration in  migrations:
        if not checkExitBuildScript('migration', migration):
            _cur.execute(migrations[migration])
            _insertBuildScript('migration', migration, migrations[migration]):
            _p('Migration "'+str(migration)+'" executed')

def buildSeed():
    seeds = directory.readSeed()
    for seed in  seeds:
        if not checkExitBuildScript('seed', seed):
            _cur.execute(seeds[seed])
            _insertBuildScript('seed', seed, seeds[seed]):
            _p('Seed "'+str(seed)+'" executed')

def buildEvent():
    events = directory.readEvent()
    for event in  events:
        if not checkExitBuildScript('event', event):
            _cur.execute(events[event])
            _insertBuildScript('event', event, events[event]):
            _p('Event "'+str(event)+'" executed')

def buildAdmin():
    admins = directory.readAdmin()
    for admin in  admins:
        if not checkExitBuildScript('admin', admin):
            _cur.execute(admins[admin])
            _insertBuildScript('admin', admin, admins[admin]):
            _p('Admin "'+str(admin)+'" executed')

def insertBuildScript(type_, file_name_, file_):
    _cur.execute(
        "INSERT INTO panthera_migration (type, file, hash, date) VALUES (?, ?i, ?, ?)", 
        (
           type_,
           file_,
           _sha512(file_),
           round(time.time())
        )
    )
    conn.commit() 

def checkiExitBuildScript(type_, file_name_):
    _cur.execute(
         "SELECT date FROM panthera_migration WHERE type=? AND file=? AND hash=?",
         type_,
         file_name_
    )
    for date in _cur:
        return True
    return False

def checkBuildScript(type_, file_name_, file_):
    _cur.execute(
         "SELECT date FROM panthera_migration WHERE type=? AND file=? AND hash=?",
         type_,
         file_name_,
         _sha512(file_)

    )
    for date in _cur:
        return True
    return False

def build():

def migration():

def migrationTableBuild():

def migrationTableRead():

def migrationTableUpdate():

def seed():

def backupImport():

def backupExport():





from setuptools import setup

with open("README.md", "r") as readme:
     long_description = readme.read()

setup(
    name='openpanthera',
    version='0.0.1',
    description='',
    py_modules=['openpanthera'],
    package_dir={'':'src'},
    install_requires=[
        "hny-config>=0.0.1"
    ],
    extras_require={
        "dev":[
            "pytest>=6.2"
        ]
    },
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)',
        'Topic :: Utilities'
    ],
    url='https://github.com/Soldy/openPanthera',
    author='Soldy',
    long_description=long_description,
    long_description_content_type="text/markdown"
)



#!/usr/bin/python3

import os, sys
import directory as d


def menu():
    print('di Init Directory')
    print('dc Check Directory')
    print('df Fix or Update Directory')
    print('ch check migration')
    print('a  auto mode')
    print('e  exit')
    while True:
       command = input(' {OP} >> ')
       if command == 'e' :
           quit()
       if command == 'id' :
           projectInit()

menu()
